@@ -37,10 +37,10 @@ from subprocess import Popen, PIPE
 import argcomplete
 import ipaddr
 from argcomplete.completers import ChoicesCompleter
-from awscli.customizations.configure.writer import ConfigFileWriter
 from threadlocal_aws.clients import ec2, route53
 
 from n_utils import _to_str
+from n_utils.writer import ConfigFileWriter
 from n_utils.aws_infra_util import yaml_load, yaml_save
 from n_utils.ndt import find_include, find_all_includes
 from n_utils.utils import has_output_selector, select_stacks
